.. _documentation-label:

==================
Package references
==================


histogramming.py
-----------

.. automodule:: plothist.histogramming
   :members:

plotters.py
-----------

.. automodule:: plothist.plotters
   :members:

comparison.py
---------------

.. automodule:: plothist.comparison
   :members:

variable_registry.py
-----------

.. automodule:: plothist.variable_registry
   :members:

plothist_style.py
---------------

.. automodule:: plothist.plothist_style
   :members:
